==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_search.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_search.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("SEALAN_1", "Search Configuration");
define("SEALAN_2", "Number of characters displayed in search result summary:");
define("SEALAN_3", "Search sort method:");
define("SEALAN_6", "Comments");
define("SEALAN_7", "Registered Members");
define("SEALAN_10", "Display relevance value:");
define("SEALAN_11", "Allow user to select searchable areas:");
define("SEALAN_12", "Restrict time allowed between searches (max 5 mins):");
define("SEALAN_13", "Restrict to one search every");
define("SEALAN_14", "seconds");
define("SEALAN_15", "Search page accessible to user class");
define("SEALAN_16", "On");
define("SEALAN_17", "Off");
define("SEALAN_18", "Searchable Comments Areas (when comments search is activated)");
define("SEALAN_19", "Allow users to search more than one area at a time:");
define("SEALAN_20", "General Settings");
define("SEALAN_21", "Searchable Areas");
define("SEALAN_22", "Default");
define("SEALAN_23", "Alternative:");
define("SEALAN_24", "Type");
define("SEALAN_25", "User Class");
define("SEALAN_26", "Pre-Title Text");
define("SEALAN_30", "Highlight keywords on referred to page:");
define("SEALAN_31", "PHP limited to");
define("SEALAN_32", "results (leave blank for no limit)");
define("SEALAN_33", "Could not switch to MySQL sort method as this requires at least version 4.0.1 of MySQL.");
define("SEALAN_34", "Your version is currently");
define("SEALAN_35", "Searchable areas selection method:");
define("SEALAN_36", "Dropdown");
define("SEALAN_37", "Checkbox");
define("SEALAN_38", "Radio");
define("SEALAN_39", "Custom Pages");

define("LAN_SEARCH_98", "News");		// Renamed to avoid clashes
define("LAN_197", "Downloads");
define("LAN_418", "Custom Pages");

define("SEALAN_40", "Search Options");
define("SEALAN_41", "Main Page");
define("SEALAN_42", "Preferences");

define("SEALAN_43", "Edit search settings for");
define("SEALAN_44", "User class allowed to search this area");
define("SEALAN_45", "Number of results displayed per page");
define("SEALAN_46", "Number of characters in search result summary");

define("SEALAN_47", "Only match whole words:");
define("SEALAN_48", "This setting only applies when the search sort method is PHP. If your site includes Ideographic languages such as Chinese and Japanese you must have this set to off.");
define("SEALAN_49", "If your site includes Ideographic languages, such as Chinese and Japanese, you must use the PHP sort method.");


?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_search.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_search.php $
|     $Revision: 11678 $
|     $Id: lan_search.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("SEALAN_1", "Search Configuration");
define("SEALAN_2", "Number of characters displayed in search result summary:");
define("SEALAN_3", "Search sort method:");
define("SEALAN_6", "Comments");
define("SEALAN_7", "Registered Members");
define("SEALAN_10", "Display relevance value:");
define("SEALAN_11", "Allow user to select searchable areas:");
define("SEALAN_12", "Restrict time allowed between searches (max 5 mins):");
define("SEALAN_13", "Restrict to one search every");
define("SEALAN_14", "seconds");
define("SEALAN_15", "Search page accessible to user class");
define("SEALAN_16", "On");
define("SEALAN_17", "Off");
define("SEALAN_18", "Searchable Comments Areas (when comments search is activated)");
define("SEALAN_19", "Allow users to search more than one area at a time:");
define("SEALAN_20", "General Settings");
define("SEALAN_21", "Searchable Areas");
define("SEALAN_22", "Default");
define("SEALAN_23", "Alternative:");
define("SEALAN_24", "Type");
define("SEALAN_25", "User Class");
define("SEALAN_26", "Pre-Title Text");
define("SEALAN_30", "Highlight keywords on referred to page:");
define("SEALAN_31", "PHP limited to");
define("SEALAN_32", "results (leave blank for no limit)");
define("SEALAN_33", "Could not switch to MySQL sort method as this requires at least version 4.0.1 of MySQL.");
define("SEALAN_34", "Your version is currently");
define("SEALAN_35", "Searchable areas selection method:");
define("SEALAN_36", "Dropdown");
define("SEALAN_37", "Checkbox");
define("SEALAN_38", "Radio");
define("SEALAN_39", "Custom Pages");

define("LAN_SEARCH_98", "News");		// Renamed to avoid clashes
define("LAN_197", "Downloads");
define("LAN_418", "Custom Pages");

define("SEALAN_40", "Search Options");
define("SEALAN_41", "Main Page");
define("SEALAN_42", "Preferences");

define("SEALAN_43", "Edit search settings for");
define("SEALAN_44", "User class allowed to search this area");
define("SEALAN_45", "Number of results displayed per page");
define("SEALAN_46", "Number of characters in search result summary");

define("SEALAN_47", "Only match whole words:");
define("SEALAN_48", "This setting only applies when the search sort method is PHP. If your site includes Ideographic languages such as Chinese and Japanese you must have this set to off.");
define("SEALAN_49", "If your site includes Ideographic languages, such as Chinese and Japanese, you must use the PHP sort method.");


?>
